@@ -40,7 +40,7 @@ class InstagramIdCodec:
         return num
 
 
-def generate_signature(data):
+def generate_signature_old(data):
     """Generate signature of POST data for Private API"""
     body = hmac.new(
         config.IG_SIG_KEY.encode("utf-8"), data.encode("utf-8"), hashlib.sha256
@@ -52,6 +52,12 @@ def generate_signature(data):
     )
 
 
+def generate_signature(data):
+    return "signed_body=SIGNATURE.{data}".format(
+        data=urllib.parse.quote_plus(data)
+    )
+
+
 def json_value(data, *args, default=None):
     cur = data
     for a in args:
@@ -78,3 +84,8 @@ def gen_csrftoken(size=32):
 
 def dumps(data):
     return json.dumps(data, separators=(",", ":"))
+
+
+def generate_jazoest(symbols: str) -> str:
+    amount = sum(ord(s) for s in symbols)
+    return f'2{amount}'
